import * as plainCookiesDriver from './drivers/plain.js';
import * as signedCookiesDriver from './drivers/signed.js';
import * as encryptedCookiesDriver from './drivers/encrypted.js';
export class CookieClient {
    #encryption;
    constructor(encryption) {
        this.#encryption = encryption;
    }
    encrypt(key, value) {
        return encryptedCookiesDriver.pack(key, value, this.#encryption);
    }
    sign(key, value) {
        return signedCookiesDriver.pack(key, value, this.#encryption);
    }
    encode(_, value) {
        return plainCookiesDriver.pack(value);
    }
    unsign(key, value) {
        return signedCookiesDriver.canUnpack(value)
            ? signedCookiesDriver.unpack(key, value, this.#encryption)
            : null;
    }
    decrypt(key, value) {
        return encryptedCookiesDriver.canUnpack(value)
            ? encryptedCookiesDriver.unpack(key, value, this.#encryption)
            : null;
    }
    decode(_, value) {
        return plainCookiesDriver.canUnpack(value) ? plainCookiesDriver.unpack(value) : null;
    }
    parse(key, value) {
        if (signedCookiesDriver.canUnpack(value)) {
            return signedCookiesDriver.unpack(key, value, this.#encryption);
        }
        if (encryptedCookiesDriver.canUnpack(value)) {
            return encryptedCookiesDriver.unpack(key, value, this.#encryption);
        }
        if (plainCookiesDriver.canUnpack(value)) {
            return plainCookiesDriver.unpack(value);
        }
    }
}
