import cookie from 'cookie';
import { CookieClient } from './client.js';
export class CookieParser {
    #client;
    #cachedCookies = {
        signedCookies: {},
        plainCookies: {},
        encryptedCookies: {},
    };
    #cookies;
    constructor(cookieHeader, encryption) {
        this.#client = new CookieClient(encryption);
        this.#cookies = this.#parse(cookieHeader);
    }
    #parse(cookieHeader) {
        if (!cookieHeader) {
            return {};
        }
        return cookie.parse(cookieHeader);
    }
    decode(key, encoded = true) {
        const value = this.#cookies[key];
        if (value === null || value === undefined) {
            return null;
        }
        const cache = this.#cachedCookies.plainCookies;
        if (cache[key] !== undefined) {
            return cache[key];
        }
        const parsed = encoded ? this.#client.decode(key, value) : value;
        if (parsed !== null) {
            cache[key] = parsed;
        }
        return parsed;
    }
    unsign(key) {
        const value = this.#cookies[key];
        if (value === null || value === undefined) {
            return null;
        }
        const cache = this.#cachedCookies.signedCookies;
        if (cache[key] !== undefined) {
            return cache[key];
        }
        const parsed = this.#client.unsign(key, value);
        if (parsed !== null) {
            cache[key] = parsed;
        }
        return parsed;
    }
    decrypt(key) {
        const value = this.#cookies[key];
        if (value === null || value === undefined) {
            return null;
        }
        const cache = this.#cachedCookies.encryptedCookies;
        if (cache[key] !== undefined) {
            return cache[key];
        }
        const parsed = this.#client.decrypt(key, value);
        if (parsed !== null) {
            cache[key] = parsed;
        }
        return parsed;
    }
    list() {
        return this.#cookies;
    }
}
