import cookie from 'cookie';
import string from '@poppinss/utils/string';
import { CookieClient } from './client.js';
export class CookieSerializer {
    #client;
    constructor(encryption) {
        this.#client = new CookieClient(encryption);
    }
    #serializeAsCookie(key, value, options) {
        let expires = options?.expires;
        if (typeof expires === 'function') {
            expires = expires();
        }
        let maxAge = options?.maxAge ? string.seconds.parse(options?.maxAge) : undefined;
        const parsedOptions = Object.assign({}, options, { maxAge, expires });
        return cookie.serialize(key, value, parsedOptions);
    }
    encode(key, value, options) {
        const packedValue = options?.encode === false ? value : this.#client.encode(key, value);
        if (packedValue === null || packedValue === undefined) {
            return null;
        }
        return this.#serializeAsCookie(key, packedValue, options);
    }
    sign(key, value, options) {
        const packedValue = this.#client.sign(key, value);
        if (packedValue === null) {
            return null;
        }
        return this.#serializeAsCookie(key, packedValue, options);
    }
    encrypt(key, value, options) {
        const packedValue = this.#client.encrypt(key, value);
        if (packedValue === null) {
            return null;
        }
        return this.#serializeAsCookie(key, packedValue, options);
    }
}
