import { inspect } from 'node:util';
import { Macroable } from '@poppinss/macroable';
import { RuntimeException } from '@poppinss/utils';
import { asyncLocalStorage } from './local_storage.js';
export class HttpContext extends Macroable {
    request;
    response;
    logger;
    static get usingAsyncLocalStorage() {
        return asyncLocalStorage.isEnabled;
    }
    static get() {
        if (!this.usingAsyncLocalStorage || !asyncLocalStorage.storage) {
            return null;
        }
        return asyncLocalStorage.storage.getStore() || null;
    }
    static getOrFail() {
        if (!this.usingAsyncLocalStorage || !asyncLocalStorage.storage) {
            throw new RuntimeException('HTTP context is not available. Enable "useAsyncLocalStorage" inside "config/app.ts" file');
        }
        const store = this.get();
        if (!store) {
            throw new RuntimeException('Http context is not available outside of an HTTP request');
        }
        return store;
    }
    static runOutsideContext(callback, ...args) {
        if (!asyncLocalStorage.storage) {
            return callback(...args);
        }
        return asyncLocalStorage.storage.exit(callback, ...args);
    }
    route;
    routeKey;
    params = {};
    subdomains = {};
    constructor(request, response, logger) {
        super();
        this.request = request;
        this.response = response;
        this.logger = logger;
        this.request.ctx = this;
        this.response.ctx = this;
    }
    inspect() {
        return inspect(this, false, 1, true);
    }
}
