import type Middleware from '@poppinss/middleware';
import type { ContainerResolver } from '@adonisjs/fold';
import type { HttpContext } from '../http_context/main.js';
import type { MiddlewareFn, ParsedGlobalMiddleware } from './middleware.js';
export type MatchItRouteToken = RouteMatcher & {
    old: string;
    type: 0 | 1 | 2 | 3;
    val: string;
    end: string;
};
export type RouteFn = (ctx: HttpContext) => any;
export type StoreRouteHandler = RouteFn | {
    name: string;
    handle: (resolver: ContainerResolver, ...args: [ctx: HttpContext, ...injections: any[]]) => any;
};
export type StoreRouteMiddleware = MiddlewareFn | ({
    name?: string;
    args?: any[];
} & ParsedGlobalMiddleware);
export type StoreRouteNode = {
    execute: (route: StoreRouteNode, resolver: ContainerResolver, ctx: HttpContext) => any;
    name?: string;
    pattern: string;
    handler: StoreRouteHandler;
    middleware: Middleware<StoreRouteMiddleware>;
    meta: Record<string, any>;
};
export type StoreMethodNode = {
    tokens: MatchItRouteToken[][];
    routeKeys: {
        [pattern: string]: string;
    };
    routes: {
        [pattern: string]: StoreRouteNode;
    };
};
export type StoreDomainNode = {
    [method: string]: StoreMethodNode;
};
export type StoreRoutesTree = {
    tokens: MatchItRouteToken[][];
    domains: {
        [domain: string]: StoreDomainNode;
    };
};
export type MatchedRoute = {
    route: StoreRouteNode;
    routeKey: string;
    params: Record<string, any>;
    subdomains: Record<string, any>;
};
export type RouteMatcher = {
    match?: RegExp;
    cast?: (value: string) => any;
};
export type RouteMatchers = {
    [param: string]: RouteMatcher;
};
export type RouteJSON = StoreRouteNode & {
    methods: string[];
    domain: string;
    matchers: RouteMatchers;
};
export type ResourceActionNames = 'create' | 'index' | 'store' | 'show' | 'edit' | 'update' | 'destroy';
export type MakeUrlOptions = {
    qs?: Record<string, any>;
    domain?: string;
    prefixUrl?: string;
    disableRouteLookup?: boolean;
};
export type MakeSignedUrlOptions = MakeUrlOptions & {
    expiresIn?: string | number;
    purpose?: string;
};
